@@ -1,4 +1,5 @@
-"""Handles communication with a Control4 Director, and provides functions for getting details about items on the Director.
+"""Handles communication with a Control4 Director, and provides functions for
+   getting details about items on the Director.
 """
 import aiohttp
 import async_timeout
@@ -19,13 +20,21 @@ class C4Director:
         Parameters:
             `ip` - The IP address of the Control4 Director/Controller.
 
-            `director_bearer_token` - The bearer token used to authenticate with the Director. See `pyControl4.account.C4Account.getDirectorBearerToken` for how to get this.
+            `director_bearer_token` - The bearer token used to authenticate
+                                      with the Director.
+                See `pyControl4.account.C4Account.getDirectorBearerToken`
+                for how to get this.
 
-            `session` - (Optional) Allows the use of an `aiohttp.ClientSession` object for all network requests. This session will not be closed by the library.
-            If not provided, the library will open and close its own `ClientSession`s as needed.
+            `session` - (Optional) Allows the use of an
+                        `aiohttp.ClientSession` object
+                        for all network requests. This
+                        session will not be closed by the library.
+                        If not provided, the library will open and
+                        close its own `ClientSession`s as needed.
         """
         self.base_url = "https://{}".format(ip)
         self.headers = {"Authorization": "Bearer {}".format(director_bearer_token)}
+        self.director_bearer_token = director_bearer_token
         self.session = session_no_verify_ssl
 
     async def sendGetRequest(self, uri):
@@ -33,7 +42,8 @@ class C4Director:
         Returns the Director's JSON response as a string.
 
         Parameters:
-            `uri` - The API URI to send the request to. Do not include the IP address of the Director.
+            `uri` - The API URI to send the request to. Do not include the IP
+                    address of the Director.
         """
         if self.session is None:
             async with aiohttp.ClientSession(
@@ -54,11 +64,13 @@ class C4Director:
                     return await resp.text()
 
     async def sendPostRequest(self, uri, command, params, async_variable=True):
-        """Sends a POST request to the specified API URI. Used to send commands to the Director.
+        """Sends a POST request to the specified API URI. Used to send commands
+           to the Director.
         Returns the Director's JSON response as a string.
 
         Parameters:
-            `uri` - The API URI to send the request to. Do not include the IP address of the Director.
+            `uri` - The API URI to send the request to. Do not include the IP
+                    address of the Director.
 
             `command` - The Control4 command to send.
 
@@ -87,6 +99,21 @@ class C4Director:
                     await checkResponseForError(await resp.text())
                     return await resp.text()
 
+    async def getAllItemsByCategory(self, category):
+        """Returns a JSON list of items related to a particular category.
+
+        Parameters:
+            `category` - Control4 Category Name: controllers, comfort, lights,
+                         cameras, sensors, audio_video,
+                         motorization, thermostats, motors,
+                         control4_remote_hub,
+                         outlet_wireless_dimmer, voice-scene
+        """
+        return_list = await self.sendGetRequest(
+            "/api/v1/categories/{}".format(category)
+        )
+        return return_list
+
     async def getAllItemInfo(self):
         """Returns a JSON list of all the items on the Director."""
         return await self.sendGetRequest("/api/v1/items")
@@ -118,19 +145,25 @@ class C4Director:
         return await self.sendGetRequest("/api/v1/items/{}/variables".format(item_id))
 
     async def getItemVariableValue(self, item_id, var_name):
-        """Returns the value of the specified variable for the specified item as a string.
+        """Returns the value of the specified variable for the
+        specified item as a string.
 
         Parameters:
             `item_id` - The Control4 item ID.
 
-            `var_name` - The Control4 variable name.
+            `var_name` - The Control4 variable name or names.
         """
+
+        if isinstance(var_name, (tuple, list, set)):
+            var_name = ",".join(var_name)
+
         data = await self.sendGetRequest(
             "/api/v1/items/{}/variables?varnames={}".format(item_id, var_name)
         )
         if data == "[]":
             raise ValueError(
-                "Empty response recieved from Director! The variable {} doesn't seem to exist for item {}.".format(
+                "Empty response recieved from Director! The variable {} \
+                    doesn't seem to exist for item {}.".format(
                     var_name, item_id
                 )
             )
@@ -138,17 +171,22 @@ class C4Director:
         return jsonDictionary[0]["value"]
 
     async def getAllItemVariableValue(self, var_name):
-        """Returns a dictionary with the values of the specified variable for all items that have it.
+        """Returns a dictionary with the values of the specified variable
+        for all items that have it.
 
         Parameters:
-            `var_name` - The Control4 variable name.
+            `var_name` - The Control4 variable name or names.
         """
+        if isinstance(var_name, (tuple, list, set)):
+            var_name = ",".join(var_name)
+
         data = await self.sendGetRequest(
             "/api/v1/items/variables?varnames={}".format(var_name)
         )
         if data == "[]":
             raise ValueError(
-                "Empty response recieved from Director! The variable {} doesn't seem to exist for any items.".format(
+                "Empty response recieved from Director! The variable {} \
+                    doesn't seem to exist for any items.".format(
                     var_name
                 )
             )
@@ -178,3 +216,87 @@ class C4Director:
             `item_id` - The Control4 item ID.
         """
         return await self.sendGetRequest("/api/v1/items/{}/bindings".format(item_id))
+
+    async def getUiConfiguration(self):
+        """Returns a dictionary of the JSON Control4 App UI Configuration enumerating rooms and capabilities
+
+        Returns:
+
+            {
+             "experiences": [
+                {
+                 "type": "watch",
+                 "sources": {
+                    "source": [
+                     {
+                      "id": 59,
+                      "type": "HDMI"
+                     },
+                     {
+                      "id": 946,
+                      "type": "HDMI"
+                     },
+                     {
+                      "id": 950,
+                      "type": "HDMI"
+                     },
+                     {
+                      "id": 33,
+                      "type": "VIDEO_SELECTION"
+                     }
+                    ]
+                },
+                 "active": false,
+                 "room_id": 9,
+                 "username": "primaryuser"
+                },
+                {
+                 "type": "listen",
+                 "sources": {
+                    "source": [
+                    {
+                     "id": 298,
+                     "type": "DIGITAL_AUDIO_SERVER",
+                     "name": "My Music"
+                    },
+                    {
+                     "id": 302,
+                     "type": "AUDIO_SELECTION",
+                     "name": "Stations"
+                    },
+                    {
+                     "id": 306,
+                     "type": "DIGITAL_AUDIO_SERVER",
+                     "name": "ShairBridge"
+                    },
+                    {
+                     "id": 937,
+                     "type": "DIGITAL_AUDIO_SERVER",
+                     "name": "Spotify Connect"
+                    },
+                    {
+                     "id": 100002,
+                     "type": "DIGITAL_AUDIO_CLIENT",
+                     "name": "Digital Media"
+                    }
+                   ]
+                },
+                 "active": false,
+                 "room_id": 9,
+                 "username": "primaryuser"
+                },
+                {
+                 "type": "cameras",
+                 "sources": {
+                    "source": [
+                    {
+                     "id": 877,
+                     "type": "Camera"
+                    },
+                    ...
+                }
+                ...
+            }
+        """
+
+        return await self.sendGetRequest("/api/v1/agents/ui_configuration")
